@@ -19,7 +19,7 @@
 
 #include "k3bdatadoc.h"
 
-#include <QtCore/QList>
+#include <QList>
 
 #include "k3b_export.h"
 
@@ -34,7 +34,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        MovixDoc( QObject* parent = 0 );
+        explicit MovixDoc( QObject* parent = 0 );
         virtual ~MovixDoc();
 
         virtual Type type() const { return MovixProject; }
