@@ -17,7 +17,7 @@
 
 #include "ui_base_k3bdataimagesettings.h"
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 namespace K3b {
 
@@ -30,7 +30,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DataImageSettingsWidget( QWidget* parent = 0 );
+        explicit DataImageSettingsWidget( QWidget* parent = 0 );
         ~DataImageSettingsWidget();
 
         void load( const IsoOptions& );
