@@ -15,7 +15,7 @@
 #ifndef _K3B_VIDEODVDTITLEDELEGATE_H_
 #define _K3B_VIDEODVDTITLEDELEGATE_H_
 
-#include <QtWidgets/QStyledItemDelegate>
+#include <QStyledItemDelegate>
 
 namespace K3b {
 
@@ -24,7 +24,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        VideoDVDTitleDelegate( QObject* parent = 0 );
+        explicit VideoDVDTitleDelegate( QObject* parent = 0 );
         ~VideoDVDTitleDelegate();
         virtual void paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const;
         virtual QSize sizeHint( const QStyleOptionViewItem& option, const QModelIndex& index ) const;
